/* Copyright 2021, Michele Santullo
 * This file is part of remarkable_tool.
 *
 * remarkable_tool is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Remarkable_tool is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with remarkable_tool.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include <QAbstractItemModel>

namespace duck {
class Node;

class NotebookTreeModel : public QAbstractItemModel {
	Q_OBJECT
public:
	NotebookTreeModel (Node* root, QObject* parent);
	virtual ~NotebookTreeModel() noexcept;

	int rowCount (const QModelIndex& parent = QModelIndex()) const override;
	int columnCount (const QModelIndex& parent = QModelIndex()) const override;
	Qt::ItemFlags flags (const QModelIndex& index) const override;
	QModelIndex index (int row, int column, const QModelIndex& parent = QModelIndex()) const override;
	QVariant data (const QModelIndex& index, int role) const override;
	QVariant headerData (int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
	QModelIndex parent (const QModelIndex& index) const override;

	Node* root_node() { return m_tree; }
	const Node* root_node() const { return m_tree; }

private:
	Node* m_tree;
};
} //namespace duck
